// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// from gst-gir-files (https://gitlab.freedesktop.org/gstreamer/gir-files-rs.git)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "GstAncillaryMeta", sizeof(GstAncillaryMeta), alignof(GstAncillaryMeta));
    printf("%s;%zu;%zu\n", "GstAncillaryMetaField", sizeof(GstAncillaryMetaField), alignof(GstAncillaryMetaField));
    printf("%s;%zu;%zu\n", "GstColorBalanceChannel", sizeof(GstColorBalanceChannel), alignof(GstColorBalanceChannel));
    printf("%s;%zu;%zu\n", "GstColorBalanceChannelClass", sizeof(GstColorBalanceChannelClass), alignof(GstColorBalanceChannelClass));
    printf("%s;%zu;%zu\n", "GstColorBalanceInterface", sizeof(GstColorBalanceInterface), alignof(GstColorBalanceInterface));
    printf("%s;%zu;%zu\n", "GstColorBalanceType", sizeof(GstColorBalanceType), alignof(GstColorBalanceType));
    printf("%s;%zu;%zu\n", "GstNavigationCommand", sizeof(GstNavigationCommand), alignof(GstNavigationCommand));
    printf("%s;%zu;%zu\n", "GstNavigationEventType", sizeof(GstNavigationEventType), alignof(GstNavigationEventType));
    printf("%s;%zu;%zu\n", "GstNavigationInterface", sizeof(GstNavigationInterface), alignof(GstNavigationInterface));
    printf("%s;%zu;%zu\n", "GstNavigationMessageType", sizeof(GstNavigationMessageType), alignof(GstNavigationMessageType));
    printf("%s;%zu;%zu\n", "GstNavigationModifierType", sizeof(GstNavigationModifierType), alignof(GstNavigationModifierType));
    printf("%s;%zu;%zu\n", "GstNavigationQueryType", sizeof(GstNavigationQueryType), alignof(GstNavigationQueryType));
    printf("%s;%zu;%zu\n", "GstVideoAFDMeta", sizeof(GstVideoAFDMeta), alignof(GstVideoAFDMeta));
    printf("%s;%zu;%zu\n", "GstVideoAFDSpec", sizeof(GstVideoAFDSpec), alignof(GstVideoAFDSpec));
    printf("%s;%zu;%zu\n", "GstVideoAFDValue", sizeof(GstVideoAFDValue), alignof(GstVideoAFDValue));
    printf("%s;%zu;%zu\n", "GstVideoAffineTransformationMeta", sizeof(GstVideoAffineTransformationMeta), alignof(GstVideoAffineTransformationMeta));
    printf("%s;%zu;%zu\n", "GstVideoAggregator", sizeof(GstVideoAggregator), alignof(GstVideoAggregator));
    printf("%s;%zu;%zu\n", "GstVideoAggregatorClass", sizeof(GstVideoAggregatorClass), alignof(GstVideoAggregatorClass));
    printf("%s;%zu;%zu\n", "GstVideoAggregatorConvertPad", sizeof(GstVideoAggregatorConvertPad), alignof(GstVideoAggregatorConvertPad));
    printf("%s;%zu;%zu\n", "GstVideoAggregatorConvertPadClass", sizeof(GstVideoAggregatorConvertPadClass), alignof(GstVideoAggregatorConvertPadClass));
    printf("%s;%zu;%zu\n", "GstVideoAggregatorPad", sizeof(GstVideoAggregatorPad), alignof(GstVideoAggregatorPad));
    printf("%s;%zu;%zu\n", "GstVideoAggregatorPadClass", sizeof(GstVideoAggregatorPadClass), alignof(GstVideoAggregatorPadClass));
    printf("%s;%zu;%zu\n", "GstVideoAggregatorParallelConvertPad", sizeof(GstVideoAggregatorParallelConvertPad), alignof(GstVideoAggregatorParallelConvertPad));
    printf("%s;%zu;%zu\n", "GstVideoAggregatorParallelConvertPadClass", sizeof(GstVideoAggregatorParallelConvertPadClass), alignof(GstVideoAggregatorParallelConvertPadClass));
    printf("%s;%zu;%zu\n", "GstVideoAlignment", sizeof(GstVideoAlignment), alignof(GstVideoAlignment));
    printf("%s;%zu;%zu\n", "GstVideoAlphaMode", sizeof(GstVideoAlphaMode), alignof(GstVideoAlphaMode));
    printf("%s;%zu;%zu\n", "GstVideoAncillary", sizeof(GstVideoAncillary), alignof(GstVideoAncillary));
    printf("%s;%zu;%zu\n", "GstVideoAncillaryDID", sizeof(GstVideoAncillaryDID), alignof(GstVideoAncillaryDID));
    printf("%s;%zu;%zu\n", "GstVideoAncillaryDID16", sizeof(GstVideoAncillaryDID16), alignof(GstVideoAncillaryDID16));
    printf("%s;%zu;%zu\n", "GstVideoBarMeta", sizeof(GstVideoBarMeta), alignof(GstVideoBarMeta));
    printf("%s;%zu;%zu\n", "GstVideoBufferFlags", sizeof(GstVideoBufferFlags), alignof(GstVideoBufferFlags));
    printf("%s;%zu;%zu\n", "GstVideoBufferPool", sizeof(GstVideoBufferPool), alignof(GstVideoBufferPool));
    printf("%s;%zu;%zu\n", "GstVideoBufferPoolClass", sizeof(GstVideoBufferPoolClass), alignof(GstVideoBufferPoolClass));
    printf("%s;%zu;%zu\n", "GstVideoCaptionMeta", sizeof(GstVideoCaptionMeta), alignof(GstVideoCaptionMeta));
    printf("%s;%zu;%zu\n", "GstVideoCaptionType", sizeof(GstVideoCaptionType), alignof(GstVideoCaptionType));
    printf("%s;%zu;%zu\n", "GstVideoChromaFlags", sizeof(GstVideoChromaFlags), alignof(GstVideoChromaFlags));
    printf("%s;%zu;%zu\n", "GstVideoChromaMethod", sizeof(GstVideoChromaMethod), alignof(GstVideoChromaMethod));
    printf("%s;%zu;%zu\n", "GstVideoChromaMode", sizeof(GstVideoChromaMode), alignof(GstVideoChromaMode));
    printf("%s;%zu;%zu\n", "GstVideoChromaSite", sizeof(GstVideoChromaSite), alignof(GstVideoChromaSite));
    printf("%s;%zu;%zu\n", "GstVideoCodecAlphaMeta", sizeof(GstVideoCodecAlphaMeta), alignof(GstVideoCodecAlphaMeta));
    printf("%s;%zu;%zu\n", "GstVideoCodecFrame", sizeof(GstVideoCodecFrame), alignof(GstVideoCodecFrame));
    printf("%s;%zu;%zu\n", "GstVideoCodecFrameFlags", sizeof(GstVideoCodecFrameFlags), alignof(GstVideoCodecFrameFlags));
    printf("%s;%zu;%zu\n", "GstVideoCodecState", sizeof(GstVideoCodecState), alignof(GstVideoCodecState));
    printf("%s;%zu;%zu\n", "GstVideoColorMatrix", sizeof(GstVideoColorMatrix), alignof(GstVideoColorMatrix));
    printf("%s;%zu;%zu\n", "GstVideoColorPrimaries", sizeof(GstVideoColorPrimaries), alignof(GstVideoColorPrimaries));
    printf("%s;%zu;%zu\n", "GstVideoColorPrimariesInfo", sizeof(GstVideoColorPrimariesInfo), alignof(GstVideoColorPrimariesInfo));
    printf("%s;%zu;%zu\n", "GstVideoColorRange", sizeof(GstVideoColorRange), alignof(GstVideoColorRange));
    printf("%s;%zu;%zu\n", "GstVideoColorVolumeTransformation", sizeof(GstVideoColorVolumeTransformation), alignof(GstVideoColorVolumeTransformation));
    printf("%s;%zu;%zu\n", "GstVideoColorimetry", sizeof(GstVideoColorimetry), alignof(GstVideoColorimetry));
    printf("%s;%zu;%zu\n", "GstVideoContentLightLevel", sizeof(GstVideoContentLightLevel), alignof(GstVideoContentLightLevel));
    printf("%s;%zu;%zu\n", "GstVideoCropMeta", sizeof(GstVideoCropMeta), alignof(GstVideoCropMeta));
    printf("%s;%zu;%zu\n", "GstVideoDecoder", sizeof(GstVideoDecoder), alignof(GstVideoDecoder));
    printf("%s;%zu;%zu\n", "GstVideoDecoderClass", sizeof(GstVideoDecoderClass), alignof(GstVideoDecoderClass));
    printf("%s;%zu;%zu\n", "GstVideoDecoderRequestSyncPointFlags", sizeof(GstVideoDecoderRequestSyncPointFlags), alignof(GstVideoDecoderRequestSyncPointFlags));
    printf("%s;%zu;%zu\n", "GstVideoDirectionInterface", sizeof(GstVideoDirectionInterface), alignof(GstVideoDirectionInterface));
    printf("%s;%zu;%zu\n", "GstVideoDitherFlags", sizeof(GstVideoDitherFlags), alignof(GstVideoDitherFlags));
    printf("%s;%zu;%zu\n", "GstVideoDitherMethod", sizeof(GstVideoDitherMethod), alignof(GstVideoDitherMethod));
    printf("%s;%zu;%zu\n", "GstVideoDmabufPoolClass", sizeof(GstVideoDmabufPoolClass), alignof(GstVideoDmabufPoolClass));
    printf("%s;%zu;%zu\n", "GstVideoEncoder", sizeof(GstVideoEncoder), alignof(GstVideoEncoder));
    printf("%s;%zu;%zu\n", "GstVideoEncoderClass", sizeof(GstVideoEncoderClass), alignof(GstVideoEncoderClass));
    printf("%s;%zu;%zu\n", "GstVideoFieldOrder", sizeof(GstVideoFieldOrder), alignof(GstVideoFieldOrder));
    printf("%s;%zu;%zu\n", "GstVideoFilter", sizeof(GstVideoFilter), alignof(GstVideoFilter));
    printf("%s;%zu;%zu\n", "GstVideoFilterClass", sizeof(GstVideoFilterClass), alignof(GstVideoFilterClass));
    printf("%s;%zu;%zu\n", "GstVideoFlags", sizeof(GstVideoFlags), alignof(GstVideoFlags));
    printf("%s;%zu;%zu\n", "GstVideoFormat", sizeof(GstVideoFormat), alignof(GstVideoFormat));
    printf("%s;%zu;%zu\n", "GstVideoFormatFlags", sizeof(GstVideoFormatFlags), alignof(GstVideoFormatFlags));
    printf("%s;%zu;%zu\n", "GstVideoFormatInfo", sizeof(GstVideoFormatInfo), alignof(GstVideoFormatInfo));
    printf("%s;%zu;%zu\n", "GstVideoFrame", sizeof(GstVideoFrame), alignof(GstVideoFrame));
    printf("%s;%zu;%zu\n", "GstVideoFrameFlags", sizeof(GstVideoFrameFlags), alignof(GstVideoFrameFlags));
    printf("%s;%zu;%zu\n", "GstVideoFrameMapFlags", sizeof(GstVideoFrameMapFlags), alignof(GstVideoFrameMapFlags));
    printf("%s;%zu;%zu\n", "GstVideoGLTextureOrientation", sizeof(GstVideoGLTextureOrientation), alignof(GstVideoGLTextureOrientation));
    printf("%s;%zu;%zu\n", "GstVideoGLTextureType", sizeof(GstVideoGLTextureType), alignof(GstVideoGLTextureType));
    printf("%s;%zu;%zu\n", "GstVideoGLTextureUploadMeta", sizeof(GstVideoGLTextureUploadMeta), alignof(GstVideoGLTextureUploadMeta));
    printf("%s;%zu;%zu\n", "GstVideoGammaMode", sizeof(GstVideoGammaMode), alignof(GstVideoGammaMode));
    printf("%s;%zu;%zu\n", "GstVideoHDR10Plus", sizeof(GstVideoHDR10Plus), alignof(GstVideoHDR10Plus));
    printf("%s;%zu;%zu\n", "GstVideoHDRFormat", sizeof(GstVideoHDRFormat), alignof(GstVideoHDRFormat));
    printf("%s;%zu;%zu\n", "GstVideoHDRMeta", sizeof(GstVideoHDRMeta), alignof(GstVideoHDRMeta));
    printf("%s;%zu;%zu\n", "GstVideoInfo", sizeof(GstVideoInfo), alignof(GstVideoInfo));
    printf("%s;%zu;%zu\n", "GstVideoInfoDmaDrm", sizeof(GstVideoInfoDmaDrm), alignof(GstVideoInfoDmaDrm));
    printf("%s;%zu;%zu\n", "GstVideoInterlaceMode", sizeof(GstVideoInterlaceMode), alignof(GstVideoInterlaceMode));
    printf("%s;%zu;%zu\n", "GstVideoMasteringDisplayInfo", sizeof(GstVideoMasteringDisplayInfo), alignof(GstVideoMasteringDisplayInfo));
    printf("%s;%zu;%zu\n", "GstVideoMasteringDisplayInfoCoordinates", sizeof(GstVideoMasteringDisplayInfoCoordinates), alignof(GstVideoMasteringDisplayInfoCoordinates));
    printf("%s;%zu;%zu\n", "GstVideoMatrixMode", sizeof(GstVideoMatrixMode), alignof(GstVideoMatrixMode));
    printf("%s;%zu;%zu\n", "GstVideoMeta", sizeof(GstVideoMeta), alignof(GstVideoMeta));
    printf("%s;%zu;%zu\n", "GstVideoMetaTransform", sizeof(GstVideoMetaTransform), alignof(GstVideoMetaTransform));
    printf("%s;%zu;%zu\n", "GstVideoMetaTransformMatrix", sizeof(GstVideoMetaTransformMatrix), alignof(GstVideoMetaTransformMatrix));
    printf("%s;%zu;%zu\n", "GstVideoMultiviewFlags", sizeof(GstVideoMultiviewFlags), alignof(GstVideoMultiviewFlags));
    printf("%s;%zu;%zu\n", "GstVideoMultiviewFramePacking", sizeof(GstVideoMultiviewFramePacking), alignof(GstVideoMultiviewFramePacking));
    printf("%s;%zu;%zu\n", "GstVideoMultiviewMode", sizeof(GstVideoMultiviewMode), alignof(GstVideoMultiviewMode));
    printf("%s;%zu;%zu\n", "GstVideoOrientationInterface", sizeof(GstVideoOrientationInterface), alignof(GstVideoOrientationInterface));
    printf("%s;%zu;%zu\n", "GstVideoOrientationMethod", sizeof(GstVideoOrientationMethod), alignof(GstVideoOrientationMethod));
    printf("%s;%zu;%zu\n", "GstVideoOverlayCompositionMeta", sizeof(GstVideoOverlayCompositionMeta), alignof(GstVideoOverlayCompositionMeta));
    printf("%s;%zu;%zu\n", "GstVideoOverlayFormatFlags", sizeof(GstVideoOverlayFormatFlags), alignof(GstVideoOverlayFormatFlags));
    printf("%s;%zu;%zu\n", "GstVideoOverlayInterface", sizeof(GstVideoOverlayInterface), alignof(GstVideoOverlayInterface));
    printf("%s;%zu;%zu\n", "GstVideoPackFlags", sizeof(GstVideoPackFlags), alignof(GstVideoPackFlags));
    printf("%s;%zu;%zu\n", "GstVideoPrimariesMode", sizeof(GstVideoPrimariesMode), alignof(GstVideoPrimariesMode));
    printf("%s;%zu;%zu\n", "GstVideoRectangle", sizeof(GstVideoRectangle), alignof(GstVideoRectangle));
    printf("%s;%zu;%zu\n", "GstVideoRegionOfInterestMeta", sizeof(GstVideoRegionOfInterestMeta), alignof(GstVideoRegionOfInterestMeta));
    printf("%s;%zu;%zu\n", "GstVideoResampler", sizeof(GstVideoResampler), alignof(GstVideoResampler));
    printf("%s;%zu;%zu\n", "GstVideoResamplerFlags", sizeof(GstVideoResamplerFlags), alignof(GstVideoResamplerFlags));
    printf("%s;%zu;%zu\n", "GstVideoResamplerMethod", sizeof(GstVideoResamplerMethod), alignof(GstVideoResamplerMethod));
    printf("%s;%zu;%zu\n", "GstVideoSEIUserDataUnregisteredMeta", sizeof(GstVideoSEIUserDataUnregisteredMeta), alignof(GstVideoSEIUserDataUnregisteredMeta));
    printf("%s;%zu;%zu\n", "GstVideoScalerFlags", sizeof(GstVideoScalerFlags), alignof(GstVideoScalerFlags));
    printf("%s;%zu;%zu\n", "GstVideoSink", sizeof(GstVideoSink), alignof(GstVideoSink));
    printf("%s;%zu;%zu\n", "GstVideoSinkClass", sizeof(GstVideoSinkClass), alignof(GstVideoSinkClass));
    printf("%s;%zu;%zu\n", "GstVideoTileInfo", sizeof(GstVideoTileInfo), alignof(GstVideoTileInfo));
    printf("%s;%zu;%zu\n", "GstVideoTileMode", sizeof(GstVideoTileMode), alignof(GstVideoTileMode));
    printf("%s;%zu;%zu\n", "GstVideoTileType", sizeof(GstVideoTileType), alignof(GstVideoTileType));
    printf("%s;%zu;%zu\n", "GstVideoTimeCode", sizeof(GstVideoTimeCode), alignof(GstVideoTimeCode));
    printf("%s;%zu;%zu\n", "GstVideoTimeCodeConfig", sizeof(GstVideoTimeCodeConfig), alignof(GstVideoTimeCodeConfig));
    printf("%s;%zu;%zu\n", "GstVideoTimeCodeFlags", sizeof(GstVideoTimeCodeFlags), alignof(GstVideoTimeCodeFlags));
    printf("%s;%zu;%zu\n", "GstVideoTimeCodeInterval", sizeof(GstVideoTimeCodeInterval), alignof(GstVideoTimeCodeInterval));
    printf("%s;%zu;%zu\n", "GstVideoTimeCodeMeta", sizeof(GstVideoTimeCodeMeta), alignof(GstVideoTimeCodeMeta));
    printf("%s;%zu;%zu\n", "GstVideoTransferFunction", sizeof(GstVideoTransferFunction), alignof(GstVideoTransferFunction));
    printf("%s;%zu;%zu\n", "GstVideoVBIParserResult", sizeof(GstVideoVBIParserResult), alignof(GstVideoVBIParserResult));
    return 0;
}
